@@ -1,4 +1,4 @@
-#     Copyright 2013, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -29,15 +29,38 @@ PyObject *_sentinel_value = NULL;
 
 %(constant_declarations)s
 
-// Blob from which objects are unstreamed.
-static const unsigned char stream_data[] =
+#if defined(_WIN32) && defined(_NUITKA_EXE)
+#include <Windows.h>
+const unsigned char* constant_bin;
+struct __initResourceConstants
 {
-%(stream_data)s
-};
+    __initResourceConstants()
+    {
+        constant_bin = (const unsigned char*)LockResource(
+            LoadResource(
+                NULL,
+                FindResource(NULL, MAKEINTRESOURCE(3), RT_RCDATA)
+            )
+        );
+    }
+} __initResourceConstants_static_initializer;
+#else
+extern "C" const unsigned char constant_bin[];
+#endif
 
 static void __initConstants( void )
 {
+    NUITKA_MAY_BE_UNUSED PyObject *exception_type, *exception_value;
+    NUITKA_MAY_BE_UNUSED PyTracebackObject *exception_tb;
+
+#ifdef _MSC_VER
+    // Prevent unused warnings in case of simple programs.
+    (void *)exception_type; (void *)exception_value; (void *)exception_tb;
+#endif
+
 %(constant_inits)s
+
+    return;
 }
 
 void _initConstants( void )
@@ -56,10 +79,3 @@ void _initConstants( void )
     }
 }
 """
-
-template_constants_declaration = """\
-// Call this to initialize all of the below
-void _initConstants( void );
-
-%(constant_declarations)s
-"""
