@@ -147,7 +147,10 @@ int main( int argc, char *argv[] )
     PyType_Ready( &Nuitka_Method_Type );
     PyType_Ready( &Nuitka_Frame_Type );
 #if PYTHON_VERSION < 300
-    initSlotCompare();
+    _initSlotCompare();
+#endif
+#if PYTHON_VERSION >= 270
+    _initSlotIternext();
 #endif
 
     enhancePythonTypes();
@@ -329,7 +332,10 @@ MOD_INIT_DECL( %(module_identifier)s )
     PyType_Ready( &Nuitka_Method_Type );
     PyType_Ready( &Nuitka_Frame_Type );
 #if PYTHON_VERSION < 300
-    initSlotCompare();
+    _initSlotCompare();
+#endif
+#if PYTHON_VERSION >= 270
+    _initSlotIternext();
 #endif
 
     patchBuiltinModule();
