@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -56,7 +56,7 @@ def iteratorCreationTiming():
     res = tuple(gen)
     print res
 
-    print "*" * 20
+    print '*' * 20
 
     try:
         gen.next()
