@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -41,7 +41,7 @@ def lamdaContainer(x):
 
     print "Lambda defaulted gives", z()
 
-lamdaContainer("b")
+lamdaContainer('b')
 
 def lambdaGenerator():
     x = lambda : (yield 3)
